Index: uspace/app/layout/layout.c
===================================================================
--- uspace/app/layout/layout.c	(revision a76ba5f310b3db71c7ee27837278d0123689f1b7)
+++ uspace/app/layout/layout.c	(revision 6a208fc949c41203a0521f864b0efa9b3ab3f52f)
@@ -47,5 +47,5 @@
 
 /* Dispays help for layout in various levels */
-static void print_help()
+static void print_help(void)
 {
 	printf("Changes, lists or displays the current keyboard layout.\n");
Index: uspace/lib/c/generic/io/input.c
===================================================================
--- uspace/lib/c/generic/io/input.c	(revision a76ba5f310b3db71c7ee27837278d0123689f1b7)
+++ uspace/lib/c/generic/io/input.c	(revision 6a208fc949c41203a0521f864b0efa9b3ab3f52f)
@@ -254,5 +254,5 @@
 	async_exch_t *exch = async_exchange_begin(sess);
 
-	aid_t mid = async_send_0(exch, INPUT_CHANGE_LAYOUT, &call);
+	aid_t mid = async_send_0(exch, INPUT_SET_LAYOUT, &call);
 	rc = async_data_write_start(exch, layout, str_size(layout));
 
Index: uspace/lib/c/include/ipc/input.h
===================================================================
--- uspace/lib/c/include/ipc/input.h	(revision a76ba5f310b3db71c7ee27837278d0123689f1b7)
+++ uspace/lib/c/include/ipc/input.h	(revision 6a208fc949c41203a0521f864b0efa9b3ab3f52f)
@@ -40,5 +40,5 @@
 typedef enum {
 	INPUT_ACTIVATE = IPC_FIRST_USER_METHOD,
-	INPUT_CHANGE_LAYOUT,
+	INPUT_SET_LAYOUT,
 	INPUT_GET_LAYOUT
 } input_request_t;
Index: uspace/srv/hid/input/input.c
===================================================================
--- uspace/srv/hid/input/input.c	(revision a76ba5f310b3db71c7ee27837278d0123689f1b7)
+++ uspace/srv/hid/input/input.c	(revision 6a208fc949c41203a0521f864b0efa9b3ab3f52f)
@@ -137,6 +137,6 @@
 }
 
-/* Handler for IPC call INPUT_CHANGE_LAYOUT */
-static void client_change_layout_handler(ipc_call_t *call)
+/* Handler for IPC call INPUT_SET_LAYOUT */
+static void client_set_layout_srv(ipc_call_t *call)
 {
 	void *layout_name;
@@ -153,5 +153,5 @@
 
 /* Handler for IPC call INPUT_GET_LAYOUT */
-static void client_get_layout_handler(ipc_call_t *call)
+static void client_get_layout_srv(ipc_call_t *call)
 {
 	const char *layout_name = layout_active->name;
@@ -419,9 +419,9 @@
 				async_answer_0(&call, EOK);
 				break;
-			case INPUT_CHANGE_LAYOUT:
-				client_change_layout_handler(&call);
+			case INPUT_SET_LAYOUT:
+				client_set_layout_srv(&call);
 				break;
 			case INPUT_GET_LAYOUT:
-				client_get_layout_handler(&call);
+				client_get_layout_srv(&call);
 				break;
 			default:
